;; Generated package description from nano-modeline.el  -*- no-byte-compile: t -*-
(define-package "nano-modeline" "1.0.0.0.20230602.115716" "N Λ N O modeline" '((emacs "27.1")) :commit "255136d3fc4bf09b2869eceb1ffc4c60f7cc70bc" :maintainer '("Nicolas P. Rougier" . "Nicolas.Rougier@inria.fr") :keywords '("convenience" "mode-line" "header-line") :url "https://github.com/rougier/nano-modeline")
